==> igniteui-webcomponents-layouts-4.8.1.tgz: package/esm5/lib/igc-tool-action-checkbox-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionCheckboxComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionCheckboxComponent, _super);
    function IgcToolActionCheckboxComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionCheckboxComponent.prototype.createImplementation = function () {
        return new ToolActionCheckbox();
    };
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionCheckboxComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionCheckboxComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent == null) {
                var names = getAllPropertyNames(IgcToolActionCheckboxComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = names;
            }
            return IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent.register = function () {
        if (!IgcToolActionCheckboxComponent._isElementRegistered) {
            IgcToolActionCheckboxComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionCheckboxComponent.htmlTagName, IgcToolActionCheckboxComponent);
        }
    };
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.f8;
        },
        set: function (v) {
            this.i.f8 = ensureBool(v);
            this._a("isChecked", this.i.f8);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.gy);
        },
        set: function (v) {
            this.i.gy = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.gy));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.gu);
        },
        set: function (v) {
            this.i.gu = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.gu));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gw);
        },
        set: function (v) {
            this.i.gw = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.gw));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gs);
        },
        set: function (v) {
            this.i.gs = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.gs));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.gz);
        },
        set: function (v) {
            this.i.gz = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.gz));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.gv);
        },
        set: function (v) {
            this.i.gv = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.gv));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gx);
        },
        set: function (v) {
            this.i.gx = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.gx));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gt);
        },
        set: function (v) {
            this.i.gt = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.gt));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent.prototype.fromInfo = function (info) {
        this.i.ej(info);
    };
    IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = null;
    IgcToolActionCheckboxComponent.htmlTagName = "igc-tool-action-checkbox";
    IgcToolActionCheckboxComponent._isElementRegistered = false;
    return IgcToolActionCheckboxComponent;
}(IgcToolActionComponent));
export { IgcToolActionCheckboxComponent };

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm5/lib/igc-tool-action-checkbox-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionCheckboxComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionCheckboxComponent, _super);
    function IgcToolActionCheckboxComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionCheckboxComponent.prototype.createImplementation = function () {
        return new ToolActionCheckbox();
    };
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionCheckboxComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionCheckboxComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent == null) {
                var names = getAllPropertyNames(IgcToolActionCheckboxComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = names;
            }
            return IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent.register = function () {
        if (!IgcToolActionCheckboxComponent._isElementRegistered) {
            IgcToolActionCheckboxComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionCheckboxComponent.htmlTagName, IgcToolActionCheckboxComponent);
        }
    };
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            this.i.hb = ensureBool(v);
            this._a("isChecked", this.i.hb);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h1);
        },
        set: function (v) {
            this.i.h1 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.h1));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hx);
        },
        set: function (v) {
            this.i.hx = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.hx));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hz);
        },
        set: function (v) {
            this.i.hz = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.hz));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hv);
        },
        set: function (v) {
            this.i.hv = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.hv));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h2);
        },
        set: function (v) {
            this.i.h2 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.h2));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hy);
        },
        set: function (v) {
            this.i.hy = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.hy));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h0);
        },
        set: function (v) {
            this.i.h0 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.h0));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionCheckboxComponent.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hw);
        },
        set: function (v) {
            this.i.hw = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.hw));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = null;
    IgcToolActionCheckboxComponent.htmlTagName = "igc-tool-action-checkbox";
    IgcToolActionCheckboxComponent._isElementRegistered = false;
    return IgcToolActionCheckboxComponent;
}(IgcToolActionComponent));
export { IgcToolActionCheckboxComponent };
